@@ -1,7 +1,8 @@
 import functools
 import requests
 from flask_heroku_auth import utils
-from flask import abort, g, request
+from flask import abort, g, request, current_app
+import json
 
 
 def build_client():
@@ -46,6 +47,10 @@ class HerokuAPIAuth(object):
         r = build_client()
         resp = r.get('/account', auth=(username, password))
         if resp.status_code != 200:
+            current_app.logger.info(
+                    'API Auth: Call to /account returned %s' % resp.status_code)
+            current_app.logger.info(
+                    'API Auth: %s' % json.dumps(resp.json()))
             abort(401)
 
         f = self.app.view_functions.get(request.endpoint)
@@ -53,6 +58,8 @@ class HerokuAPIAuth(object):
         email = resp.json().get('email')
 
         if getattr(f, '_herokai_only', False) and not utils.is_herokai(email):
+            current_app.logger.info(
+                    'API Auth: Non-Herokai attempting to access Herokai Only')
             abort(401)
 
         g._herokuauth_api_user = username
