@@ -2,7 +2,7 @@ from flask_heroku_auth.oauth import HerokuOAuth
 from flask_heroku_auth.api import HerokuAPIAuth
 from flask_heroku_auth import utils
 import functools
-from flask import g, request, abort
+from flask import g, request, abort, current_app
 
 class HerokuAuth(object):
 
@@ -52,12 +52,18 @@ class HerokuAuth(object):
         """
         @functools.wraps(f)
         def dec(*args, **kwargs):
+            current_app.logger.info(
+                    'API Authentication: Starting')
             g._heroku_auth_method = "api"
             if not request.authorization:
+                current_app.logger.info(
+                    'API Authentication Failed: Basic Auth not Provided')
                 abort(401)
             u = request.authorization.get('username')
             p = request.authorization.get('password')
             self._api.authenticate(u, p)
+            current_app.logger.info(
+                    'API Authentication: Successful')
             return f(*args, **kwargs)
         return dec
 
